

set -ex



test -L $PREFIX/lib/libcusolver.so
test -L $PREFIX/lib/libcusolverMg.so
test -f $PREFIX/lib/pkgconfig/cusolver*.pc
test -f $PREFIX/targets/sbsa-linux/include/cusolverDn.h
test -f $PREFIX/targets/sbsa-linux/include/cusolverMg.h
test -f $PREFIX/targets/sbsa-linux/include/cusolverRf.h
test -f $PREFIX/targets/sbsa-linux/include/cusolverSp.h
test -f $PREFIX/targets/sbsa-linux/include/cusolverSp_LOWLEVEL_PREVIEW.h
test -f $PREFIX/targets/sbsa-linux/include/cusolver_common.h
test -L $PREFIX/targets/sbsa-linux/lib/libcusolver.so
test -L $PREFIX/targets/sbsa-linux/lib/libcusolverMg.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libcusolver.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libcusolverMg.so
exit 0
